Assign unique user identifiers (user IDs) that identify members, and enable activities performed on ePHI Systems with a
user identifiers to be traced to an individual workforce member and provide access to ePHI Systems.
